# Models

Except for `base_model`, each folder contains a model, or a group of variants of a model. `base_model` contains an abstract class that should be inherited by the other concrete models.

Most models are adapted from other sources and each of them are subjected to different licenses. Inside each folder you can find links to the original sources, as well as their licenses.

Please be sure to check if the license of the model you want to use is compatible with your application. Also, make sure you cite the respective sources when using these models.

More information about the models can be found [in this page of the documentation](https://ptlflow.readthedocs.io/en/latest/models/models_list.html).